Learn R Programming

SFM (version 0.2.1)

concrete_slump: Data Frame 'concrete_slump'

Description

This is the Concrete Slump Test data set containing various features of concrete mixtures and their slump test results.

Usage

data("concrete_slump")

Arguments

Format

A data frame with 103 rows and 11 columns.

  • Cement: Amount of cement in kg/m³.

  • Slag: Amount of blast furnace slag in kg/m³.

  • Flyash: Amount of fly ash in kg/m³.

  • Water: Amount of water in kg/m³.

  • SP: Amount of superplasticizer in kg/m³.

  • Coarseagg: Amount of coarse aggregate in kg/m³.

  • Fineagg: Amount of fine aggregate in kg/m³.

  • SLUMP: Slump of the concrete mixture in mm.

  • FLOW: Flow of the concrete mixture in mm.

  • CompressiveStrength: Compressive strength of the concrete in MPa.

Examples

Run this code
data(concrete_slump)

Run the code above in your browser using DataLab